/*
 *  ngtk/c/ngtk_boxes.c
 *
 *  Copyright (C) 1998, 1999 Gabriel Fort <gabx@tfz.net>
 *
 */

/*----------------------------------------------------------------------------

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the 
    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
    Boston, MA  02111-1307  USA.

----------------------------------------------------------------------------*/
#include <ngtk/ngtk.h>

void ngtk_minibox(ngtk_win_t *cur_win, int height, int width, int top, int left, int show, int up, int refresh)
{
    int i;
    WINDOW *win = cur_win->win;
    attr_t save_attrs = win->_attrs;

    chtype ulc, urc, llc, lrc, vl, hl;
    int u_left_c, b_right_c, u_left_a, b_right_a;

    if (!up) {
        u_left_c = 0;
        b_right_c = 7;
        u_left_a = A_NORMAL;
        b_right_a = A_BOLD;
    } else {
        u_left_c = 7;
        b_right_c = 0;
        u_left_a = A_BOLD;
        b_right_a = A_NORMAL;
    }

    if (!show) {
        ulc = urc = llc = lrc = vl = hl = 32;
    } else {
        ulc = ACS_ULCORNER;
        urc = ACS_URCORNER;
        llc = ACS_LLCORNER;
        lrc = ACS_LRCORNER;
        vl = ACS_VLINE;
        hl = ACS_HLINE;
    }

    setfg(cur_win, u_left_c, u_left_a);
    mvwaddch(win, top, left, ulc);
    mvwaddch(win, top+height-1, left, llc);

    setfg(cur_win, b_right_c, b_right_a);
    mvwaddch(win, top, left+width, urc);
    mvwaddch(win, top+height-1, left+width, lrc);
    setfg(cur_win, u_left_c, u_left_a);

    for (i=1;i<=height-2;i++) {
        mvwaddch(win, top+i, left, vl);
        setfg(cur_win, b_right_c, b_right_a);
        mvwaddch(win, top+i, left+width, vl);
        setfg(cur_win, u_left_c, u_left_a);
    }
    for (i=1;i<=width-1;i++) {
        mvwaddch(win, top, left+i, hl);
        setfg(cur_win, b_right_c, b_right_a);
        mvwaddch(win, top+height-1, left+i, hl);
        setfg(cur_win, u_left_c, u_left_a);
    }
    wattrset(win, save_attrs);

    wnoutrefresh(win);

    if (refresh)
        doupdate();
}

ngtk_win_t *ngtk_mkbox(int height, int width, int top, int left, int cpair, int attr, char *title, int echo, int shadow, int refresh)
{
    int npos = (width / 2) - (strlen(title) / 2);
    
    ngtk_win_t *box = ngtk_push_win(height, width, top, left, cpair, attr, \
                                    echo, shadow);
    ngtk_clrwin(box->win, 32, 1);

    ngtk_minibox(box, height, width-1, 0, 0, 1, 1, 0);
    setfg(box, 7, A_BOLD);
    if (strlen(title))
        mvwprintw(box->win, 0, npos-1, " %s ", title);

    wattrset(box->win, COLOR_PAIR(cpair) | attr);

    wnoutrefresh(box->win);

    if (refresh)
        doupdate();

    return(box);
}
